@@ -695,7 +695,7 @@ class FinetuningIn(BaseModel):
     gpu_type: Optional[GPUType] = None
     gpu_count: Optional[int] = None
 
-    autotrain_params: Optional[Union[LLMTrainingParams, SGFinetuneParams]] = None
+    autotrain_params: Optional[LLMTrainingParams] = None
 
 
 class FinetuningJobDB(FinetuningIn):
