@@ -107,7 +107,7 @@ class LLMTrainingParams(SGFinetuneParams):
         None,
         title="If not None, this will activate NEFTune noise embeddings. This can drastically improve model performance for instruction fine-tuning.",
     )
-    use_deepspeed: Optional[str] = Field("stage_2", title="stage_2, stage_3, or None")
+    use_deepspeed: Optional[str] = Field(None, title="stage_2, stage_3, or None")
     apply_chat_template: Optional[Literal["zephyr", "chatml", "tokenizer"]] = Field(
         None, title="Apply chat template, one of: None, zephyr, chatml or tokenizer"
     )
