@@ -538,7 +538,7 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
 @click.option(
     "--use_peft",
     cls=CategorizedMutuallyExclusiveOption,
-    required=False,
+    required=True,
     type=click.Choice(["lora", "adalora", "ia3", "llama_adapter"]),
     default=DEFAULT_LLM_PARAMS.use_peft,
     show_default=True,
@@ -637,11 +637,9 @@ def create_ft_job(ft_req_data: FinetuningIn, quiet: bool = False):
     "--use_deepspeed",  # FIXME: disable this option if any PEFT method is enable, or maybe we can even use them together?
     cls=CategorizedMutuallyExclusiveOption,
     required=False,
-    default=DEFAULT_LLM_PARAMS.use_deepspeed,
-    show_default=True,
-    help="Use DeepSpeed for training. Will be ignored if any PEFT method is enabled.",
+    type=click.Choice(["stage_2", "stage_3"], case_sensitive=True),
+    help="Use DeepSpeed for training.",
     category="Compute optimization configuration options",
-    mutually_exclusive=["use_peft"],
 )
 @click.option(
     "--disable_gradient_checkpointing",
